SetExtensions<E> extension
Extensions for Set operations and utilities.
- on
-
- Set<
E>
- Set<
Methods
-
differenceWith(
Set< E> other) → Set<E> -
Available on Set<
Returns a new set with the elements ofE> , provided by the SetExtensions extensionotherremoved from this set. -
intersectionWith(
Set< E> other) → Set<E> -
Available on Set<
Returns a new set containing only the elements present in both sets.E> , provided by the SetExtensions extension -
isDisjointWith(
Set< E> other) → bool -
Available on Set<
ReturnsE> , provided by the SetExtensions extensiontrueif the two sets share no elements. -
isSubsetOf(
Set< E> other) → bool -
Available on Set<
ReturnsE> , provided by the SetExtensions extensiontrueif every element of this set is contained inother. -
isSupersetOf(
Set< E> other) → bool -
Available on Set<
ReturnsE> , provided by the SetExtensions extensiontrueif this set contains every element ofother. -
symmetricDifference(
Set< E> other) → Set<E> -
Available on Set<
Returns the elements present in exactly one of the two sets.E> , provided by the SetExtensions extension -
toggle(
E element) → Set< E> -
Available on Set<
Returns a new set withE> , provided by the SetExtensions extensionelementadded if absent, or removed if present. -
unionWith(
Set< E> other) → Set<E> -
Available on Set<
Returns a new set containing the elements in either this set orE> , provided by the SetExtensions extensionother.